import { Component, OnInit, ViewEncapsulation } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';
import { IdentityService } from 'app/modules/polyglot/identity/services/identity.service';

@Component({
  selector: 'sign-up-compose',
  templateUrl: './sign-up-compose.component.html',
  encapsulation: ViewEncapsulation.None,
})
export class SignUpComposeComponent implements OnInit {
  signupComposeForm!: FormGroup;
  copyFields: { cc: boolean; bcc: boolean } = {
    cc: false,
    bcc: false,
  };
  quillModules: any = {
    toolbar: [
      ['bold', 'italic', 'underline'],
      [{ align: [] }, { list: 'ordered' }, { list: 'bullet' }],
      ['clean'],
    ],
  };

  /**
   * Constructor
   */
  constructor(
    public matDialogRef: MatDialogRef<SignUpComposeComponent>,
    private _formBuilder: FormBuilder,
    private _identityService: IdentityService
  ) {
    this._identityService
      .checkUsernameForDuplication('administrator')
      .then((v) => console.log('result: ', v));
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {
    // Create the form
    this.signupComposeForm = this._formBuilder.group({
      referalCode: ['', [Validators.required]],
      username: ['', [Validators.required]],
      nickname: ['', Validators.required],
      password: ['', [Validators.required]],
      passwordConfirm: ['', [Validators.required]],
      exchangePassword: ['', [Validators.required]],
      mobilePhoneNumber: ['', [Validators.required]],
      bankName: ['', [Validators.required]],
      accountNumber: ['', [Validators.required]],
      accountHolder: ['', [Validators.required]],
    });
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Show the copy field with the given field name
   *
   * @param name
   */
  showCopyField(name: string): void {
    // Return if the name is not one of the available names
    if (name !== 'cc' && name !== 'bcc') {
      return;
    }

    // Show the field
    this.copyFields[name] = true;
  }

  /**
   * Save and close
   */
  saveAndClose(): void {
    // Save the message as a draft
    this.saveAsDraft();

    // Close the dialog
    this.matDialogRef.close();
  }

  /**
   * Discard the message
   */
  discard(): void {}

  /**
   * Save the message as a draft
   */
  saveAsDraft(): void {}

  /**
   * Send the message
   */
  send(): void {}

  __checkUsernameDuplicate(event: FocusEvent): void {
    const username = this.signupComposeForm.get('username')?.value;
    // console.log(event, '::', username);
    this._identityService
      .checkUsernameForDuplication(username)
      .then((isUse: boolean) => {
        if (!!isUse) {
          this.signupComposeForm
            .get('username')
            ?.setErrors({ usernameDuplicate: true });
        }
        // this._changeDetectorRef.markForCheck();
      });
  }

  __checkNickname(event: FocusEvent): void {
    const nickname = this.signupComposeForm.get('nickname')?.value;

    this._identityService
      .checkNicknameForDuplication(nickname)
      .then((isUse: boolean) => {
        if (!!isUse) {
          this.signupComposeForm
            .get('nickname')
            ?.setErrors({ nicknameDuplicate: true });
        }
        // this._changeDetectorRef.markForCheck();
      });
  }
}
